@@ -1,6 +1,6 @@
 use std::{
     fs,
-    io::{Error, ErrorKind, Result, Write},
+    io::{Error, Result, Write},
 };
 
 use log::info;
@@ -21,7 +21,7 @@ pub fn generate(env: &Env) {
 
     let path = env.config.auto_path.join(file_name_sys("lib"));
 
-    info!("Generating file {:?}", path);
+    info!("Generating file {path:?}");
     save_to_file(&path, env.config.make_backup, |w| generate_lib(w, env));
 }
 
@@ -70,8 +70,7 @@ fn generate_lib(w: &mut dyn Write, env: &Env) -> Result<()> {
             && enums.iter().all(|x| x.functions.is_empty())
             && unions.iter().all(|x| x.functions.is_empty()))
     {
-        return Err(Error::new(
-            ErrorKind::Other,
+        return Err(Error::other(
             "No shared library found, but functions were found",
         ));
     }
@@ -256,7 +255,7 @@ fn generate_constants(w: &mut dyn Write, env: &Env, constants: &[Constant]) -> R
             x @ Err(..) => ("//", x.into_string()),
         };
         let mut value = constant.value.clone();
-        if type_ == "*mut c_char" {
+        if type_ == "*mut c_char" || type_ == "*const c_char" {
             type_ = "&[u8]".into();
             value = format!("b\"{}\\0\"", general::escape_string(&value));
         } else if type_ == "gboolean" {
