@@ -1,10 +1,11 @@
-use crate::writer::untabber::Untabber;
 use std::{
     fs::{self, File},
     io::{BufWriter, Result, Write},
     path::Path,
 };
 
+use crate::writer::untabber::Untabber;
+
 pub fn save_to_file<P, F>(path: P, make_backup: bool, mut closure: F)
 where
     P: AsRef<Path>,
@@ -17,13 +18,12 @@ where
 
     if make_backup {
         let _backuped = create_backup(path)
-            .unwrap_or_else(|why| panic!("couldn't create backup for {:?}: {:?}", path, why));
+            .unwrap_or_else(|why| panic!("couldn't create backup for {path:?}: {why:?}"));
     }
-    let file =
-        File::create(path).unwrap_or_else(|why| panic!("couldn't create {:?}: {}", path, why));
+    let file = File::create(path).unwrap_or_else(|why| panic!("couldn't create {path:?}: {why}"));
     let writer = BufWriter::new(file);
     let mut untabber = Untabber::new(Box::new(writer));
-    closure(&mut untabber).unwrap_or_else(|why| panic!("couldn't write to {:?}: {:?}", path, why));
+    closure(&mut untabber).unwrap_or_else(|why| panic!("couldn't write to {path:?}: {why:?}"));
 }
 
 /// Create .bak file
